AlphabetDecoder constructor

const AlphabetDecoder({
  1. required int bits,
  2. required List<int> alphabet,
  3. int? padding,
})

Creates a new AlphabetDecoder instance.

Parameters:

  • bits is bit-length of a single word in the output
  • The alphabet contains mapping from input word to output word.
  • If padding is not null, conversion will stop immediately upon encountering this character.

Implementation

const AlphabetDecoder({
  required super.bits,
  required this.alphabet,
  this.padding,
});