alphabet property

List<int> alphabet
final

The reverse lookup table mapping a character code to its word value, with -1 for character codes that are not part of the alphabet.

Implementation

final List<int> alphabet;