AlphabetEncoder class
A ByteEncoder that maps each output word to a character code through an alphabet lookup table, optionally appending a padding character.
This backs the alphabet-based codecs such as Base-32 and Base-64.
- Inheritance
-
- Object
- Converter<
Iterable< int> , Iterable<int> > - BitConverter
- BitEncoder
- ByteEncoder
- AlphabetEncoder
Constructors
-
AlphabetEncoder({required int bits, required List<
int> alphabet, int? padding}) -
Creates a new AlphabetEncoder instance.
const
Properties
-
alphabet
→ List<
int> -
The lookup table mapping each output word value to its character code.
final
- bits → int
-
The bit-length of a single word in the encoded output.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → int?
-
The padding character.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → int
-
The bit-length of the input array elements.
The value should be between 2 to 64.
finalinherited
- target → int
-
The bit-length of the output array elements.
The value should be between 2 to 64.
no setteroverride
Methods
-
bind(
Stream< Iterable< stream) → Stream<int> >Iterable< int> > -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
covariant List< int> input) → Uint8List -
Converts
inputarray of numbers with bit-length of source to an array of numbers with bit-length of target. Theinputarray will be treated as a sequence of bits to convert.override -
fuse<
TT> (Converter< Iterable< other) → Converter<int> , TT>Iterable< int> , TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< Iterable< sink) → Sink<int> >Iterable< int> > -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited