AlphabetEncoder constructor

const AlphabetEncoder({
  1. required int bits,
  2. required List<int> alphabet,
  3. int? padding,
})

Creates a new AlphabetEncoder instance.

Parameters:

  • bits is bit-length of a single word in the output
  • The alphabet contains mapping from input word to output word.
  • The output array will be padded with the padding to make the length of the array to be divisible by source.

Implementation

const AlphabetEncoder({
  required super.bits,
  required this.alphabet,
  this.padding,
});