padding property

int? padding
final

The padding character.

The output array will be padded with this character to make the length of the array to be divisible by source.

Implementation

final int? padding;