z constant
Base32Codec
const z
Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of z-base-32:
ybndrfg8ejkmcpqxot1uwisza345h769
The alphabet designed in a way so that the easier characters occur more frequently, thus making it more human readable.
It is not padded.
Implementation
static const Base32Codec z = Base32Codec._(
encoder: Base32Encoder(
alphabet: _base32EncodingZ,
),
decoder: Base32Decoder(
alphabet: _base32DecodingZ,
),
);