Base32Decoder constructor

const Base32Decoder({
  1. required List<int> alphabet,
  2. int? padding,
})

Creates a new Base32Decoder instance.

Parameters:

  • The alphabet maps each input character to its 5-bit word.
  • If padding is not null, trailing occurrences of it are stripped before decoding.

Implementation

const Base32Decoder({
  required super.alphabet,
  super.padding,
}) : super(bits: 5);