convert abstract method
Converts encoded array of numbers with bit-length of source to an array
of numbers with bit-length of target. The encoded array will be treated
as a sequence of bits to convert.
If the encoded array contains negative numbers or numbers having more than
the source bits, it will be treated as the end of the input sequence.
After consuming all of input sequence, if there are some non-zero partial word remains, it will throw FormatException.
Implementation
@override
Uint8List convert(covariant List<int> encoded);