param method

CryptDataBuilder param(
  1. String name,
  2. dynamic value
)

Set a parameter value.

The parameter name must not exceed 32 characters in length and must be a sequence of characters in: [a-z0-9-].

If value is not a String, it will be converted to one with toString. As a string, it must be a sequence of characters in [a-zA-Z0-9/+.-].

Throws:

Implementation

CryptDataBuilder param(String name, dynamic value) {
  if (value == null) {
    throw ArgumentError.notNull('value');
  }
  _params[name] = value.toString();
  return this;
}