Argon2Type enum

The Argon2 types

Inheritance
Available extensions

Values

argon2d → const Argon2Type
const Argon2Type._('argon2d')
argon2i → const Argon2Type
const Argon2Type._('argon2i')
argon2id → const Argon2Type
const Argon2Type._('argon2id')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
Name of this type
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromName(String name) Argon2Type
Gets the type from string name

Constants

values → const List<Argon2Type>
A constant List of the values in this enum, in order of their declaration.