toHexBytes function
Converts 8-bit integer sequence to Base-16 and returns the ASCII bytes.
This is the same as toHex but returns the encoded characters as a Uint8List of ASCII codes, skipping the intermediate String.
Parameters:
inputis a sequence of 8-bit integers.- If
upperis true, the uppercase standard alphabet is used. codecis the Base16Codec to use. It is derived from the other parameters if not provided.
Implementation
Uint8List toHexBytes(
List<int> input, {
Base16Codec? codec,
bool upper = false,
}) {
codec ??= _codecFromParameters(upper: upper);
return codec.encoder.convert(input);
}